Learn R Programming

sketchy (version 1.0.5)

check_urls: Check urls in dynamic report files

Description

check_urls Check urls in dynamic report files (.md, .Rmd & .qmd)

Usage

check_urls(path = ".")

Value

A url_checker_db object with an added class with a custom print method.

Arguments

path

Path to the directory containing the files to be checked. Default is current directory.

Author

Nan Xiao (me@nanx.me)

Details

The function can be used to check if url addresses in dynamic reports are broken. Taken from Nan Xiao's blogpost (https://nanx.me/blog/post/rmarkdown-quarto-link-checker/).

References

Araya-Salas, M., Arriaga, A. (2023), sketchy: research compendiums for data analysis in R. R package version 1.0.3. Xiao, N. (2023). A General-Purpose Link Checker for R Markdown and Quarto Projects. Blog post. https://nanx.me/blog/post/rmarkdown-quarto-link-checker/

See Also

add_to_gitignore, make_compendium

Examples

Run this code
{
data(compendiums)

# make compendiums
make_compendium(name = "my_compendium", path = tempdir(),
format = "basic", force = TRUE)

# check urls in scripts
check_urls(path = file.path(tempdir(), "./scripts"))
}

Run the code above in your browser using DataLab