Learn R Programming

sketchy (version 1.0.5)

open_wd: Open working directory

Description

open_wd opens the working directory in the default file browser.

Usage

open_wd(path = ".", verbose = TRUE)

Value

Opens the working directory using the default file browser.

Arguments

path

Directory path to be opened. By default it's the working directory.

verbose

Logical to control whether the 'path' is printed in the console. Default is TRUE.

Author

Marcelo Araya-Salas (marcelo.araya@ucr.ac.cr)

Details

The function opens the working directory using the default file browser and prints the working directory in the R console. This function aims to simplify the manipulation of files and folders in a project.

References

Araya-Salas, M., Arriaga, A. (2023), sketchy: research compendiums for data analysis in R. R package version 1.0.3.

See Also

spot_unused_files

Examples

Run this code
{
open_wd()
}

Run the code above in your browser using DataLab