Learn R Programming

sketchy (version 1.0.5)

sketchy-package: sketchy: create custom research compendiums

Description

`sketchy` is intended to facilitate the use of research compendiums for data analysis in the R environment. Standard research compendiums provide a easily recognizable means for organizing digital materials, allowing other researchers to inspect, reproduce, and build upon that research.

Arguments

Author

Marcelo Araya-Salas, Beatriz Willink & Andrea Arriaga

Maintainer: Marcelo Araya-Salas (marcelo.araya@ucr.ac.cr)

Details

The main features of the package are:

  • Creation of (customized) folder structure

  • Simplify the inclusion of big data files with version control software and online collaborative platforms (e.g. github)

License: GPL (>= 2)

See Also