The function opens the working directory using the default file browser
and prints the working directory in the R console. This function aims to simplify
the manipulation of files and folders in a project.
References
Araya-Salas, M., Arriaga, A. (2023), sketchy: research compendiums for data analysis in R. R package version 1.0.3.