powered by
print_skeleton prints the folder structure of a research compendium.
print_skeleton
print_skeleton(path = ".", comments = NULL, folders = NULL)
The folder skeleton is printed in the console.
path to the directory to be printed. Default is current directory.
A character string with the comments to be added to each folder in the graphical representation of the folder skeleton printed on the console.
A character vector including the name of the sub-directories of the project.
Marcelo Araya-Salas (marcelo.araya@ucr.ac.cr)
The function prints the folder structure of an existing project.
Araya-Salas, M., Arriaga, A. (2023), sketchy: research compendiums for data analysis in R. R package version 1.0.3.
compendiums, make_compendium
compendiums
make_compendium
{ data(compendiums) make_compendium(name = "my_other_compendium", path = tempdir(), format = "basic") print_skeleton(path = file.path(tempdir(), "mycompendium")) }
Run the code above in your browser using DataLab